summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--tests/client_dsa_key.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/client_dsa_key.c b/tests/client_dsa_key.c
index eb2794ea81..9e5dec3cda 100644
--- a/tests/client_dsa_key.c
+++ b/tests/client_dsa_key.c
@@ -42,8 +42,8 @@
#include "utils.h"
#include "cert-common.h"
/* Test for correct operation when a client uses a DSA key when the server
* has DSA signatures enabled but not the client.
*
*/
@@ -98,7 +98,7 @@ void doit(void)
exit(1);
}
- test_cli_serv_cert(serv_cred, cli_cred, "NORMAL:+DHE-DSS:+SIGN-DSA-SHA1", "NORMAL:-DHE-DSS:-SIGN-DSA-SHA1", "localhost");
+ test_cli_serv_cert(serv_cred, cli_cred, "NORMAL:+DHE-DSS:+SIGN-DSA-SHA1", "NORMAL:-VERS-TLS-ALL:+VERS-TLS1.2:-DHE-DSS:+SIGN-DSA-SHA1", "localhost");
gnutls_certificate_free_credentials(serv_cred);
gnutls_certificate_free_credentials(cli_cred);
@@ -42,8 +42,8 @@
#include "utils.h"
#include "cert-common.h"
-/* Test for correct operation when a client uses a DSA key when the server
- * has DSA signatures enabled but not the client.
+/* Test for correct operation when a client uses a DSA key and
+ * explicitly enables DSA signatures under TLS 1.2.
*
*/